Enum Class Health.Status

java.lang.Object
java.lang.Enum<Health.Status>
dev.voidframework.healthcheck.Health.Status
All Implemented Interfaces:
Serializable, Comparable<Health.Status>, Constable
Enclosing class:
Health

public static enum Health.Status extends Enum<Health.Status>
Possible status.
Since:
1.0.0
  • Enum Constant Details

    • DOWN

      public static final Health.Status DOWN
      Service is not running... or dead.
      Since:
      1.0.0
    • UP

      public static final Health.Status UP
      Service is running.
      Since:
      1.0.0
  • Method Details

    • values

      public static Health.Status[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Health.Status valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null