Package dev.voidframework.healthcheck
package dev.voidframework.healthcheck
-
ClassDescriptionRepresents the health status of a component.Possible status.This interface allows you to define a health checker.Health check manager takes care of executing the various hooks defined by the use of the
HealthCheckerannotation.