Uses of Package
dev.voidframework.healthcheck
Packages that use dev.voidframework.healthcheck
Package
Description
-
Classes in dev.voidframework.healthcheck used by dev.voidframework.healthcheckClassDescriptionRepresents the health status of a component.Possible status.This interface allows you to define a health checker.
-
Classes in dev.voidframework.healthcheck used by dev.voidframework.healthcheck.checkerClassDescriptionRepresents the health status of a component.This interface allows you to define a health checker.
-
Classes in dev.voidframework.healthcheck used by dev.voidframework.healthcheck.moduleClassDescriptionHealth check manager takes care of executing the various hooks defined by the use of the
HealthCheckerannotation.